
# Slot: has food component


holds between food and one or more chemical substances composing it, irrespective of nutritional value (i.e. could also be a contaminant or additive)

URI: [biolink:has_food_component](https://w3id.org/biolink/vocab/has_food_component)


## Domain and Range

[ChemicalSubstance](ChemicalSubstance.md) &#8594;  <sub>0..\*</sub> [ChemicalSubstance](ChemicalSubstance.md)

## Parents

 *  is_a: [has part](has_part.md)

## Children

 *  [has nutrient](has_nutrient.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |

